@@ -319,7 +319,7 @@ class ImageRecognition(object):
         accs = [] 
         recalls = []
         precisions = [] 
-        for i in iteration_needed: 
+        for i in range(iteration_needed): 
             x_val, y_val = next(val_generator)
             feed_dict = {}
             feed_dict[self.input_placeholder] = x_val
